<?php
/**
 * Plugin Name: Add-on Explainer
 * Plugin URI: https://dspartners.jp/addon-explainer
 * Description: インストール済みのプラグインの目的や機能を初心者にも一目で分かるように表示するプラグインです。
 * Version: 1.0.0
 * Author: Manus AI
 * Author URI: https://dspartners.jp/
 * Text Domain: add-on-explainer
 * Domain Path: /languages
 * License: GPL v2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 */

// 直接アクセス禁止
if (!defined('ABSPATH')) {
    exit;
}

// プラグインのバージョン
define('ADDON_EXPLAINER_VERSION', '1.0.0');

// プラグインのパス
define('ADDON_EXPLAINER_PATH', plugin_dir_path(__FILE__));

// プラグインのURL
define('ADDON_EXPLAINER_URL', plugin_dir_url(__FILE__));

// プラグイン情報クラスの読み込み
require_once ADDON_EXPLAINER_PATH . 'includes/class-plugin-info.php';

/**
 * プラグインの初期化
 */
function addon_explainer_init() {
    // 管理画面のみで動作
    if (!is_admin()) {
        return;
    }

    // 翻訳ファイルの読み込み
    load_plugin_textdomain('add-on-explainer', false, dirname(plugin_basename(__FILE__)) . '/languages');

    // スタイルとスクリプトの読み込み
    add_action('admin_enqueue_scripts', 'addon_explainer_enqueue_scripts');

    // プラグイン一覧ページのカラム追加
    add_filter('manage_plugins_columns', 'addon_explainer_add_columns');
    add_action('manage_plugins_custom_column', 'addon_explainer_custom_column', 10, 3);

    // チュートリアル表示設定のAJAXハンドラー
    add_action('wp_ajax_addon_explainer_hide_tutorial', 'addon_explainer_hide_tutorial');

    // プラグイン有効化時のアクション
    register_activation_hook(__FILE__, 'addon_explainer_activate');

    // プラグイン無効化時のアクション
    register_deactivation_hook(__FILE__, 'addon_explainer_deactivate');
}
add_action('plugins_loaded', 'addon_explainer_init');

/**
 * スタイルとスクリプトの読み込み
 */
function addon_explainer_enqueue_scripts($hook) {
    // プラグイン一覧ページのみで読み込む
    if ('plugins.php' !== $hook) {
        return;
    }

    // CSSの読み込み
    wp_enqueue_style(
        'addon-explainer-admin-style',
        ADDON_EXPLAINER_URL . 'assets/css/admin-style.css',
        array(),
        ADDON_EXPLAINER_VERSION
    );

    // JavaScriptの読み込み
    wp_enqueue_script(
        'addon-explainer-admin-script',
        ADDON_EXPLAINER_URL . 'assets/js/admin-script.js',
        array('jquery'),
        ADDON_EXPLAINER_VERSION,
        true
    );

    // チュートリアル表示の判定
    $show_tutorial = get_option('addon_explainer_show_tutorial', true);

    // JavaScriptに渡すデータ
    wp_localize_script(
        'addon-explainer-admin-script',
        'addonExplainerData',
        array(
            'ajaxUrl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('addon-explainer-nonce'),
            'showTutorial' => $show_tutorial,
        )
    );
}

/**
 * プラグイン一覧ページにカラムを追加
 */
function addon_explainer_add_columns($columns) {
    $new_columns = array();

    foreach ($columns as $key => $value) {
        $new_columns[$key] = $value;
        
        // 説明の後に「目的」カラムを追加
        if ($key === 'description') {
            $new_columns['plugin_purpose'] = esc_html__('目的', 'add-on-explainer');
        }
    }

    return $new_columns;
}

/**
 * カスタムカラムの内容を表示
 */
function addon_explainer_custom_column($column_name, $plugin_file, $plugin_data) {
    if ('plugin_purpose' !== $column_name) {
        return;
    }

    // プラグイン情報クラスのインスタンス化
    $plugin_info = new Plugin_Explainer_Info();
    
    // プラグインの目的を取得
    $purpose = $plugin_info->get_plugin_purpose($plugin_file, $plugin_data);
    
    // カテゴリに基づいたアイコンを取得
    $category = $plugin_info->get_plugin_category($plugin_file, $plugin_data);
    $icon = $plugin_info->get_category_icon($category);
    
    // 表示
    echo '<div class="plugin-purpose-wrapper category-' . esc_attr($category) . '">';
    echo '<span class="plugin-category-icon">' . esc_html($icon) . '</span>';
    echo '<span class="plugin-purpose-text">' . esc_html($purpose) . '</span>';
    
    // 詳細情報のポップアップ用データ
    $details = $plugin_info->get_plugin_details($plugin_file, $plugin_data);
    echo '<div class="plugin-details-popup" style="display:none;">';
    echo '<h4>' . esc_html($plugin_data['Name']) . ' ' . esc_html__('の詳細', 'add-on-explainer') . '</h4>';
    echo '<p class="plugin-main-purpose"><strong>' . esc_html__('主な目的:', 'add-on-explainer') . '</strong> ' . esc_html($purpose) . '</p>';
    
    if (!empty($details['features'])) {
        echo '<div class="plugin-features">';
        echo '<strong>' . esc_html__('主な機能:', 'add-on-explainer') . '</strong>';
        echo '<ul>';
        foreach ($details['features'] as $feature) {
            echo '<li>' . esc_html($feature) . '</li>';
        }
        echo '</ul>';
        echo '</div>';
    }
    
    if (!empty($details['tips'])) {
        echo '<div class="plugin-beginner-tips">';
        echo '<strong>' . esc_html__('初心者向けヒント:', 'add-on-explainer') . '</strong>';
        echo '<p>' . esc_html($details['tips']) . '</p>';
        echo '</div>';
    }
    
    echo '</div>'; // .plugin-details-popup
    echo '</div>'; // .plugin-purpose-wrapper
}

/**
 * チュートリアル非表示設定のAJAXハンドラー
 */
function addon_explainer_hide_tutorial() {
    // nonce確認
    check_ajax_referer('addon-explainer-nonce', 'nonce');
    
    // オプション更新
    update_option('addon_explainer_show_tutorial', false);
    
    wp_die();
}

/**
 * プラグイン有効化時の処理
 */
function addon_explainer_activate() {
    // 初回有効化時の処理
    if (get_option('addon_explainer_installed') === false) {
        add_option('addon_explainer_installed', time());
        add_option('addon_explainer_show_tutorial', true);
    }
    
    // バージョン情報の更新
    update_option('addon_explainer_version', ADDON_EXPLAINER_VERSION);
    
    // キャッシュの初期化
    delete_transient('addon_explainer_cache');
}

/**
 * プラグイン無効化時の処理
 */
function addon_explainer_deactivate() {
    // キャッシュの削除
    delete_transient('addon_explainer_cache');
}
