<?php
/**
 * プラグイン情報取得クラス
 */
class Plugin_Explainer_Info {
    
    /**
     * プラグインカテゴリのデータベース
     */
    private $categories = array(
        'security' => array(
            'keywords' => array('security', 'firewall', 'malware', 'spam', 'protection', 'セキュリティ', '保護', 'スパム対策'),
            'icon' => '🔒',
            'color' => '#e74c3c',
            'description' => 'サイトを保護し、セキュリティを強化するプラグイン'
        ),
        'seo' => array(
            'keywords' => array('seo', 'search engine', 'ranking', '検索エンジン', 'メタタグ', 'サイトマップ'),
            'icon' => '🔍',
            'color' => '#3498db',
            'description' => '検索エンジン最適化を支援するプラグイン'
        ),
        'performance' => array(
            'keywords' => array('cache', 'speed', 'performance', 'optimization', 'キャッシュ', '高速化', '最適化', 'パフォーマンス'),
            'icon' => '⚡',
            'color' => '#2ecc71',
            'description' => 'サイトの表示速度を向上させるプラグイン'
        ),
        'content' => array(
            'keywords' => array('editor', 'content', 'post', 'page', 'media', 'エディタ', 'コンテンツ', '投稿'),
            'icon' => '📝',
            'color' => '#9b59b6',
            'description' => 'コンテンツ作成や編集を支援するプラグイン'
        ),
        'social' => array(
            'keywords' => array('social', 'share', 'facebook', 'twitter', 'instagram', 'ソーシャル', 'シェア'),
            'icon' => '📱',
            'color' => '#e67e22',
            'description' => 'SNS連携や共有機能を提供するプラグイン'
        ),
        'ecommerce' => array(
            'keywords' => array('shop', 'store', 'ecommerce', 'woocommerce', 'payment', 'ショップ', '決済', 'EC'),
            'icon' => '🛒',
            'color' => '#f1c40f',
            'description' => 'オンラインショップ運営を支援するプラグイン'
        ),
        'form' => array(
            'keywords' => array('form', 'contact', 'email', 'フォーム', 'お問い合わせ', 'メール'),
            'icon' => '✉️',
            'color' => '#1abc9c',
            'description' => 'お問い合わせフォームや各種フォームを作成するプラグイン'
        ),
        'backup' => array(
            'keywords' => array('backup', 'restore', 'migration', 'バックアップ', '復元', '移行'),
            'icon' => '💾',
            'color' => '#34495e',
            'description' => 'サイトのバックアップや移行を支援するプラグイン'
        ),
        'analytics' => array(
            'keywords' => array('analytics', 'statistics', 'tracking', '分析', '統計', 'トラッキング'),
            'icon' => '📊',
            'color' => '#7f8c8d',
            'description' => 'アクセス解析や統計情報を提供するプラグイン'
        ),
        'utility' => array(
            'keywords' => array('utility', 'tool', 'helper', 'ユーティリティ', 'ツール', '補助'),
            'icon' => '🔧',
            'color' => '#95a5a6',
            'description' => '様々な便利機能を提供するユーティリティプラグイン'
        )
    );
    
    /**
     * プラグインの目的を取得
     */
    public function get_plugin_purpose($plugin_file, $plugin_data) {
        // キャッシュから取得を試みる
        $cache = get_transient('plugin_explainer_cache');
        if (false !== $cache && isset($cache[$plugin_file]['purpose'])) {
            return $cache[$plugin_file]['purpose'];
        }
        
        // 説明文から目的を抽出
        $description = isset($plugin_data['Description']) ? $plugin_data['Description'] : '';
        
        // 説明が空の場合
        if (empty($description)) {
            return '情報がありません';
        }
        
        // 説明が長い場合は短縮
        if (mb_strlen($description) > 100) {
            $short_desc = mb_substr($description, 0, 100) . '...';
        } else {
            $short_desc = $description;
        }
        
        // カテゴリを取得
        $category = $this->get_plugin_category($plugin_file, $plugin_data);
        
        // カテゴリに基づいた説明を追加
        if (isset($this->categories[$category]['description'])) {
            $purpose = $this->categories[$category]['description'];
        } else {
            $purpose = $short_desc;
        }
        
        // キャッシュに保存
        $this->update_cache($plugin_file, 'purpose', $purpose);
        
        return $purpose;
    }
    
    /**
     * プラグインのカテゴリを取得
     */
    public function get_plugin_category($plugin_file, $plugin_data) {
        // キャッシュから取得を試みる
        $cache = get_transient('plugin_explainer_cache');
        if (false !== $cache && isset($cache[$plugin_file]['category'])) {
            return $cache[$plugin_file]['category'];
        }
        
        // 説明文とプラグイン名からカテゴリを判定
        $text_to_analyze = $plugin_data['Name'] . ' ' . (isset($plugin_data['Description']) ? $plugin_data['Description'] : '');
        $text_to_analyze = strtolower($text_to_analyze);
        
        $matched_category = 'utility'; // デフォルトカテゴリ
        $max_matches = 0;
        
        foreach ($this->categories as $category => $data) {
            $matches = 0;
            foreach ($data['keywords'] as $keyword) {
                if (strpos($text_to_analyze, strtolower($keyword)) !== false) {
                    $matches++;
                }
            }
            
            if ($matches > $max_matches) {
                $max_matches = $matches;
                $matched_category = $category;
            }
        }
        
        // キャッシュに保存
        $this->update_cache($plugin_file, 'category', $matched_category);
        
        return $matched_category;
    }
    
    /**
     * カテゴリに対応するアイコンを取得
     */
    public function get_category_icon($category) {
        if (isset($this->categories[$category]['icon'])) {
            return $this->categories[$category]['icon'];
        }
        
        return '🔌'; // デフォルトアイコン
    }
    
    /**
     * プラグインの詳細情報を取得
     */
    public function get_plugin_details($plugin_file, $plugin_data) {
        // キャッシュから取得を試みる
        $cache = get_transient('plugin_explainer_cache');
        if (false !== $cache && isset($cache[$plugin_file]['details'])) {
            return $cache[$plugin_file]['details'];
        }
        
        $description = isset($plugin_data['Description']) ? $plugin_data['Description'] : '';
        $category = $this->get_plugin_category($plugin_file, $plugin_data);
        
        // 機能リストの生成（説明文から抽出）
        $features = $this->extract_features($description);
        
        // 初心者向けヒント
        $tips = $this->generate_beginner_tips($plugin_file, $plugin_data, $category);
        
        $details = array(
            'features' => $features,
            'tips' => $tips,
        );
        
        // キャッシュに保存
        $this->update_cache($plugin_file, 'details', $details);
        
        return $details;
    }
    
    /**
     * 説明文から機能リストを抽出
     */
    private function extract_features($description) {
        $features = array();
        
        // 説明が空の場合
        if (empty($description)) {
            return $features;
        }
        
        // 文を分割
        $sentences = preg_split('/[.。!！?？]/', $description, -1, PREG_SPLIT_NO_EMPTY);
        
        // 最大5つの文を機能として抽出
        $count = 0;
        foreach ($sentences as $sentence) {
            $sentence = trim($sentence);
            if (!empty($sentence) && mb_strlen($sentence) > 10) {
                $features[] = $sentence;
                $count++;
                
                if ($count >= 5) {
                    break;
                }
            }
        }
        
        return $features;
    }
    
    /**
     * 初心者向けヒントを生成
     */
    private function generate_beginner_tips($plugin_file, $plugin_data, $category) {
        $tips = '';
        
        switch ($category) {
            case 'security':
                $tips = 'このプラグインはサイトのセキュリティを強化します。基本設定だけでも効果があります。';
                break;
            case 'seo':
                $tips = '検索エンジンでの表示順位向上に役立ちます。記事を書く際に表示される設定項目を活用しましょう。';
                break;
            case 'performance':
                $tips = 'サイトの表示速度を改善します。初期設定のままでも効果が期待できます。';
                break;
            case 'content':
                $tips = 'コンテンツ作成をサポートするプラグインです。エディタ画面で新しいボタンや機能が追加されます。';
                break;
            case 'social':
                $tips = 'SNSとの連携機能を提供します。記事に共有ボタンを設置したい場合に便利です。';
                break;
            case 'ecommerce':
                $tips = 'オンラインショップの運営に必要な機能を提供します。商品登録や決済設定が必要です。';
                break;
            case 'form':
                $tips = 'お問い合わせフォームなどを作成できます。設定後、ショートコードを記事や固定ページに貼り付けて使います。';
                break;
            case 'backup':
                $tips = 'サイトのバックアップを作成します。定期的なバックアップスケジュールの設定をおすすめします。';
                break;
            case 'analytics':
                $tips = 'アクセス解析機能を提供します。ダッシュボードに統計情報が表示されるようになります。';
                break;
            default:
                $tips = 'このプラグインは様々な便利機能を提供します。設定画面で必要な機能を有効化してください。';
        }
        
        return $tips;
    }
    
    /**
     * キャッシュを更新
     */
    private function update_cache($plugin_file, $key, $value) {
        $cache = get_transient('plugin_explainer_cache');
        
        if (false === $cache) {
            $cache = array();
        }
        
        if (!isset($cache[$plugin_file])) {
            $cache[$plugin_file] = array();
        }
        
        $cache[$plugin_file][$key] = $value;
        
        set_transient('plugin_explainer_cache', $cache, DAY_IN_SECONDS);
    }
}
